@@ -1,14 +1,14 @@
 package Perl::Critic::Policy::BuiltinFunctions::ProhibitVoidMap;
 
-use 5.006001;
+use 5.010001;
 use strict;
 use warnings;
 use Readonly;
 
 use Perl::Critic::Utils qw{ :severities :classification is_in_void_context };
-use base 'Perl::Critic::Policy';
+use parent 'Perl::Critic::Policy';
 
-our $VERSION = '1.130';
+our $VERSION = '1.156';
 
 #-----------------------------------------------------------------------------
 
