@@ -1,14 +1,14 @@
 package Perl::Critic::Policy::TestingAndDebugging::ProhibitProlongedStrictureOverride;
 
-use 5.006001;
+use 5.010001;
 use strict;
 use warnings;
 use Readonly;
 
 use Perl::Critic::Utils qw{ :severities };
-use base 'Perl::Critic::Policy';
+use parent 'Perl::Critic::Policy';
 
-our $VERSION = '1.130';
+our $VERSION = '1.156';
 
 #-----------------------------------------------------------------------------
 
@@ -36,7 +36,7 @@ sub applies_to       { return 'PPI::Statement::Include' }
 #-----------------------------------------------------------------------------
 
 sub violates {
-    my ($self, $elem, $doc) = @_;
+    my ($self, $elem, undef) = @_;
 
     return if $elem->type ne 'no';
     return if $elem->module ne 'strict';
