@@ -1,20 +1,14 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Policy/Variables/ProtectPrivateVars.pm $
-#     $Date: 2008-03-08 10:09:46 -0600 (Sat, 08 Mar 2008) $
-#   $Author: clonezone $
-# $Revision: 2163 $
-##############################################################################
-
 package Perl::Critic::Policy::Variables::ProtectPrivateVars;
 
+use 5.010001;
 use strict;
 use warnings;
 use Readonly;
 
 use Perl::Critic::Utils qw{ :severities };
-use base 'Perl::Critic::Policy';
+use parent 'Perl::Critic::Policy';
 
-our $VERSION = '1.082';
+our $VERSION = '1.156';
 
 #-----------------------------------------------------------------------------
 
@@ -25,7 +19,7 @@ Readonly::Scalar my $EXPL => q{Use published APIs};
 
 sub supported_parameters { return ()                   }
 sub default_severity     { return $SEVERITY_MEDIUM     }
-sub default_themes       { return qw(core maintenance) }
+sub default_themes       { return qw(core maintenance certrule ) }
 sub applies_to           { return 'PPI::Token::Symbol' }
 
 #-----------------------------------------------------------------------------
@@ -49,7 +43,14 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::Variables::ProtectPrivateVars
+Perl::Critic::Policy::Variables::ProtectPrivateVars - Prevent access to private vars in other packages.
+
+
+=head1 AFFILIATION
+
+This Policy is part of the core L<Perl::Critic|Perl::Critic>
+distribution.
+
 
 =head1 DESCRIPTION
 
@@ -58,21 +59,30 @@ indicate private methods and variables by inserting a leading
 underscore before the identifier.  This policy catches attempts to
 access private variables from outside the package itself.
 
+
+=head1 CONFIGURATION
+
+This Policy is not configurable except for the standard options.
+
+
 =head1 HISTORY
 
-This policy is inspired by a similar test in L<B::Lint>
+This policy is inspired by a similar test in L<B::Lint|B::Lint>
+
 
 =head1 SEE ALSO
 
-L<Perl::Critic::Policy::Subroutines::ProtectPrivateSubs>
+L<Perl::Critic::Policy::Subroutines::ProtectPrivateSubs|Perl::Critic::Policy::Subroutines::ProtectPrivateSubs>
+
 
 =head1 AUTHOR
 
 Chris Dolan <cdolan@cpan.org>
 
+
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2008 Chris Dolan.  All rights reserved.
+Copyright (c) 2006-2011 Chris Dolan.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -87,4 +97,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
