@@ -1,21 +1,21 @@
 package Perl::Critic::PolicyParameter::Behavior::Enumeration;
 
-use 5.006001;
+use 5.010001;
 use strict;
 use warnings;
 
 use Perl::Critic::Exception::Fatal::PolicyDefinition
-    qw{ &throw_policy_definition };
-use Perl::Critic::Utils qw{ :characters &words_from_string &hashify };
+    qw( throw_policy_definition );
+use Perl::Critic::Utils qw( :characters words_from_string hashify );
 
-use base qw{ Perl::Critic::PolicyParameter::Behavior };
+use parent qw{ Perl::Critic::PolicyParameter::Behavior };
 
-our $VERSION = '1.126';
+our $VERSION = '1.156';
 
 #-----------------------------------------------------------------------------
 
 sub initialize_parameter {
-    my ($self, $parameter, $specification) = @_;
+    my (undef, $parameter, $specification) = @_;
 
     my $valid_values = $specification->{enumeration_values}
         or throw_policy_definition
@@ -47,17 +47,13 @@ sub initialize_parameter {
     if ($allow_multiple_values) {
         $parameter->_set_parser(
             sub {
-                # Normally bad thing, obscuring a variable in a outer scope
+                # Normally bad thing, obscuring a variable in an outer scope
                 # with a variable with the same name is being done here in
                 # order to remain consistent with the parser function interface.
                 my ($policy, $parameter, $config_string) = @_;  ## no critic(Variables::ProhibitReusedNames)
 
                 my @potential_values;
-                my $value_string = $parameter->get_default_string();
-
-                if (defined $config_string) {
-                    $value_string = $config_string;
-                }
+                my $value_string = $config_string // $parameter->get_default_string();
 
                 if ( defined $value_string ) {
                     @potential_values = words_from_string($value_string);
@@ -88,16 +84,12 @@ sub initialize_parameter {
     } else {
         $parameter->_set_parser(
             sub {
-                # Normally bad thing, obscuring a variable in a outer scope
+                # Normally bad thing, obscuring a variable in an outer scope
                 # with a variable with the same name is being done here in
                 # order to remain consistent with the parser function interface.
                 my ($policy, $parameter, $config_string) = @_;  ## no critic(Variables::ProhibitReusedNames)
 
-                my $value_string = $parameter->get_default_string();
-
-                if (defined $config_string) {
-                    $value_string = $config_string;
-                }
+                my $value_string = $config_string // $parameter->get_default_string();
 
                 if (
                         defined $value_string
@@ -127,7 +119,7 @@ sub initialize_parameter {
 #-----------------------------------------------------------------------------
 
 sub generate_parameter_description {
-    my ($self, $parameter) = @_;
+    my (undef, $parameter) = @_;
 
     my $description = $parameter->_get_description_with_trailing_period();
     if ( $description ) {
@@ -223,7 +215,7 @@ Elliot Shank <perl@galumph.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2011 Elliot Shank.
+Copyright (c) 2006-2023 Elliot Shank.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
