@@ -1,14 +1,14 @@
 package Perl::Critic::PolicyParameter::Behavior::String;
 
-use 5.006001;
+use 5.010001;
 use strict;
 use warnings;
 
 use Perl::Critic::Utils;
 
-use base qw{ Perl::Critic::PolicyParameter::Behavior };
+use parent qw{ Perl::Critic::PolicyParameter::Behavior };
 
-our $VERSION = '1.140';
+our $VERSION = '1.156';
 
 #-----------------------------------------------------------------------------
 
@@ -29,7 +29,7 @@ sub _parse {
 #-----------------------------------------------------------------------------
 
 sub initialize_parameter {
-    my ($self, $parameter, $specification) = @_;
+    my (undef, $parameter, undef) = @_;
 
     $parameter->_set_parser(\&_parse);
 
